@@ -6,11 +6,17 @@ from core_parser_app.tools.modules.views.module import AbstractModule
 
 
 class AbstractInputButtonModule(AbstractModule, metaclass=ABCMeta):
-    """ Input Button module
-    """
+    """Input Button module"""
 
-    def __init__(self, scripts=list(), styles=list(), button_label='Send', label=None, default_value=None):
-        """ Initialize the module
+    def __init__(
+        self,
+        scripts=list(),
+        styles=list(),
+        button_label="Send",
+        label=None,
+        default_value=None,
+    ):
+        """Initialize the module
 
         Args:
             scripts:
@@ -25,7 +31,7 @@ class AbstractInputButtonModule(AbstractModule, metaclass=ABCMeta):
         self.default_value = default_value
 
     def _render_module(self, request):
-        """ Return the module rendering
+        """Return the module rendering
 
         Args:
             request:
@@ -38,5 +44,6 @@ class AbstractInputButtonModule(AbstractModule, metaclass=ABCMeta):
             params.update({"label": self.label})
         if self.default_value is not None:
             params.update({"default_value": self.default_value})
-        return AbstractModule.render_template('core_parser_app/builtin/input_button.html', params)
-
+        return AbstractModule.render_template(
+            "core_parser_app/builtin/input_button.html", params
+        )
