@@ -7,6 +7,12 @@ from django.http.response import HttpResponseBadRequest, HttpResponse
 from django.utils.html import escape
 
 from core_main_app.components.template import api as template_api
+from core_main_app.components.template_version_manager import (
+    api as template_version_manager_api,
+)
+from core_main_app.rest.template_version_manager.utils import (
+    can_user_modify_template_version_manager,
+)
 from core_parser_app.components.module import api as module_api
 
 
@@ -24,6 +30,11 @@ def delete_module(request):
 
         # get the template
         template = template_api.get(template_id)
+        # TODO: move to api level
+        template_version_manager = template_version_manager_api.get_by_version_id(
+            template_id
+        )
+        can_user_modify_template_version_manager(template_version_manager, request.user)
 
         # delete the module
         module_api.delete_module(template, xpath)
@@ -50,6 +61,11 @@ def insert_module(request):
 
         # get the template
         template = template_api.get(template_id)
+        # TODO: move to api
+        template_version_manager = template_version_manager_api.get_by_version_id(
+            template_id
+        )
+        can_user_modify_template_version_manager(template_version_manager, request.user)
 
         # add the module
         module_api.add_module(template, module_id, xpath)
