@@ -1,12 +1,11 @@
-SECRET_KEY = 'fake-key'
+SECRET_KEY = "fake-key"
 
 INSTALLED_APPS = [
     # Django apps
     # 'django.contrib.admin',
-    'django.contrib.auth',
-    'django.contrib.contenttypes',
-    'django.contrib.sites',
-
+    "django.contrib.auth",
+    "django.contrib.contenttypes",
+    "django.contrib.sites",
     # Local apps
     "tests",
 ]
@@ -25,6 +24,6 @@ DATABASES = {
 
 TEMPLATES = [
     {
-        'BACKEND': 'django.template.backends.django.DjangoTemplates',
+        "BACKEND": "django.template.backends.django.DjangoTemplates",
     },
 ]
